@@ -31,6 +31,7 @@ import time
 import sys
 import string
 import os.path
+import datetime
 
 import gtk
 import logger
@@ -51,6 +52,13 @@ currentTime = 0;
 googleEventsTouched = []
 localEventsTouched = []
 
+def update_progress(progress, value):
+	if not progress == None:
+		progress.set_fraction(value)
+		while gtk.events_pending():
+			gtk.main_iteration()
+
+
 def eventExistsLocally(id):
 	cur = dblayer.run("SELECT lid FROM Xrefs WHERE gid=?", (id,))
 	if cur:
@@ -148,9 +156,7 @@ def getNewEventsFromGoogle(pid, localSource, remoteSource, lastSync, \
 	
 	for i, e in enumerate(feed.entry):
 		current_fraction = current_fraction + fraction
-		progress.set_fraction(current_fraction)
-		while gtk.events_pending():
-			gtk.main_iteration()
+		update_progress(progress, current_fraction)
 
 		title = e.title.text
 		if e.recurrence <> None:
@@ -163,7 +169,7 @@ def getNewEventsFromGoogle(pid, localSource, remoteSource, lastSync, \
 		start_time = iso8601ToTimestamp(e.when[0].start_time)
 		end_time = iso8601ToTimestamp(e.when[0].end_time)
 		id = urllib.unquote((e.id.text.rpartition("/"))[2])
-		cdate = iso8601ToTimestamp(e.published.text)
+		cdate = time.time()
 
 		# An event is full-day if it doesn't have any
 		# timing event (only date)
@@ -206,13 +212,19 @@ def createNewGoogleEvent(evt, googleid, pid):
 	start_time = timestampToIso8601(evt.get_start())
 	end_time = timestampToIso8601(evt.get_end())
 
-	# if it's a full-day event, then we can strip the start/end dates:
+	# if it's a full-day event, then we can strip the start/end times:
 	if evt.get_fullday() == 1:
 		start_time = timestampToIso8601(int(evt.get_start())+evt.get_tzOffset())
 		end_time = timestampToIso8601(int(evt.get_end())+evt.get_tzOffset())
 		start_time = start_time[0:10]
 		end_time = end_time[0:10]
 
+		# Add artificially one day:
+		td = datetime.timedelta(1)
+		time_dt = datetime.datetime.strptime(end_time, "%Y-%m-%d")
+		time_dt = time_dt + td
+		end_time = time_dt.strftime("%Y-%m-%d")
+
 	event = gdata.calendar.CalendarEventEntry()
 	event.title = atom.Title(text=evt.get_title())
 	event.content = atom.Content(text=evt.get_description())
@@ -221,6 +233,10 @@ def createNewGoogleEvent(evt, googleid, pid):
 
 	new_event = google_api.run_google_action(google_api.gd_client.InsertEvent, event, urllib.quote('/calendar/feeds/' + googleid + '/private/full'))
 
+	if new_event == None:
+		logger.append("Got a None event....skipping")
+		return
+
 	gid = (new_event.id.text.rpartition("/"))[2]
 	# insert correspondance table entry:
 	dblayer.run("INSERT INTO Xrefs (pid, lid, gid) VALUES (?, ?, ?)", \
@@ -231,18 +247,14 @@ def getNewEventsFromLocal(pid, localSource, remoteSource, lastSync, progress):
 	# Those are new events to create in Google:
 	evts = queryNewLocalEvents(lastSync, localSource)
 	if not evts:
-		progress.set_fraction(1.0/3)
-		while gtk.events_pending():
-			gtk.main_iteration()
+		update_progress(progress, 1.0/3)
 		return
 
 	progress_inc = 1.0/3.0/len(evts)
 	progress_val = 0.0
 	for e in evts:
 		progress_val = progress_val + progress_inc
-		progress.set_fraction(progress_val)
-		while gtk.events_pending():
-			gtk.main_iteration()
+		update_progress(progress, progress_val)
 
 		event = Event(e[3], e[4], e[5], e[1], e[2], e[6], \
 				e[0], 0)
@@ -290,6 +302,10 @@ def updateGoogleEvent(evt, googleid, pid):
 		return
 
 	event = google_api.run_google_action(google_api.gd_client.GetCalendarEventEntry, urllib.quote("/calendar/feeds/" + googleid + "/private/full/" + gid))
+	if event == None:
+		logger.append("Unable to get event to update!")
+		return
+
 	start_time = timestampToIso8601(evt.get_start())
 	end_time = timestampToIso8601(evt.get_end())
 
@@ -311,18 +327,14 @@ def getUpdatedEventsFromLocal(pid, localSource, remoteSource, lastSync, progress
 	# Those are events to update in Google:
 	evts = queryUpdatedLocalEvents(lastSync, localSource)
 	if not evts:
-		progress.set_fraction(1.0/3*2)
-		while gtk.events_pending():
-			gtk.main_iteration()
+		update_progress(progress, 1.0/3*2)
 		return
 
 	progress_inc = 1.0/3.0/len(evts)
 	progress_val = 1.0/3.0
 	for e in evts:
 		progress_val = progress_val + progress_inc
-		progress.set_fraction(progress_val)
-		while gtk.events_pending():
-			gtk.main_iteration()
+		update_progress(progress, progress_val)
 
 		event = Event(e[3], e[4], e[5], e[1], e[2], e[6], \
 				e[0], 0)
@@ -333,23 +345,24 @@ def getDeletedEventsFromLocal(pid, localSource, remoteSource, lastSync, progress
 	# get all events in the Trash:
 	rows = cwrapper.getAllDeletedEvents(localSource, lastSync)
 	if not rows:
-		progress.set_fraction(1.0)
-		while gtk.events_pending():
-			gtk.main_iteration()
+		update_progress(progress, 1.0)
 		return
 
 	progress_inc = 1.0/3.0/len(rows)
 	progress_val = 1.0/3.0*2
 	for e in rows:
 		progress_val = progress_val + progress_inc
-		progress.set_fraction(progress_val)
-		while gtk.events_pending():
-			gtk.main_iteration()
+		update_progress(progress, progress_val)
 
 		gid = getGoogleIdFromLocalId(e)
 		if not gid:
 			continue
 		event = google_api.run_google_action(google_api.gd_client.GetCalendarEventEntry, urllib.quote("/calendar/feeds/" + remoteSource + "/private/full/" + gid))
+
+		if event == None:
+			logger.append("Unable to get event to delete!")
+			return 
+
 		google_api.run_google_action(google_api.gd_client.DeleteEvent, event.GetEditLink().href)
 
 def syncFromGoogle(pid, localSource, remoteSource, lastSync, progress=None):
